#
# spec file for package python-Paste
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-Paste
Version:        3.10.1
Release:        2.1
Summary:        Tools for using a Web Server Gateway Interface stack
License:        MIT
URL:            https://github.com/cdent/paste
Source:         https://files.pythonhosted.org/packages/source/p/paste/paste-%{version}.tar.gz
Patch0:         test_modified-fixup.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Suggests:       python-flup
Suggests:       python-python3-openid
BuildArch:      noarch
%python_subpackages

%description
These provide several pieces of "middleware" (or filters) that can be nested
to build web applications.  Each piece of middleware uses the WSGI (PEP 333)
interface, and should be compatible with other middleware based on those
interfaces.

%prep
%autosetup -p1 -n paste-%{version}
# remove test requiring internet access
rm tests/test_proxy.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license docs/license.txt
%doc README.rst
%{python_sitelib}/paste
%{python_sitelib}/Paste-%{version}.dist-info
%{python_sitelib}/Paste-%{version}-py*-nspkg.pth

%changelog
* Thu Aug 29 2024 pgajdos@suse.com
- python-six is not required
* Mon Jul 29 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 3.10.1
  * Correct packaging and testing when not in a clean virtualenv
- from version 3.10.0
  * Move development to https://github.com/pasteorg/paste
  * Vendor cgi.FieldStorage and cgitb.Hook
  * More cleaning of Python 2 style code.
- Adjust upstream source name in spec file
* Mon Apr 15 2024 Dirk Müller <dmueller@suse.com>
- update to 3.9.0:
  * misc bugs + please pyflakes
  * Remove unused format_environ method in watchthreads APP
* Fri Mar 22 2024 Dirk Müller <dmueller@suse.com>
- update to 3.8.0:
  * remove most python2 compatibility
* Tue Dec 12 2023 Dirk Müller <dmueller@suse.com>
- update to 3.7.1:
  * The main change for 3.7.0 and beyond is dropping support for
    Python 2. In the past it was possible to get Paste to work in
    Python 2 with some effort. That's now no longer possible. If
    Python 2 is required for some reason, use an older version of
    Paste.
- update to 3.6.1:
  * Turn on github action for tests on pull requests
  * Add a Makefile for simple automation
* Mon Aug 28 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.5.3:
  * Use importlib instead of imp with Python 3.
- Drop patch support-python-311.patch, something similar now included
  upstream.
- Switch to pyproject macros.
- Stop using greedy globs in %%files.
* Tue May  9 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Mon Jan  9 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-python-311.patch:
  * Filter Deprecationwarning for one test script.
- Remove Python 2 gubbins.
* Fri Sep  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- update to 3.5.2:
  * Fix py3 compatibility in paste.wsgilib.catch_errors (#70)
  * A Python 3 application might only define `__next__`, not `next`.  Use
    `six.next` instead.
  * This is very similar to https://github.com/cdent/paste/pull/53, and was
    apparently missed there.
* Fri Jul 15 2022 Dirk Müller <dmueller@suse.com>
- update to 3.5.1:
  * Replace deprecated threading.currentThread, getName and setDaemon
    with threading.current_thread, name and daemon.
* Tue Feb 23 2021 Markéta Machová <mmachova@suse.com>
- Get rid of broken %%ifpython3 macro
* Thu Nov 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.5.0:
  * Python 3 fixes to auth and wsgi.errors handling; notably making
  wsgi.errors text.
* Fri Oct  9 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.4.6:
  * Explicit pkg_resource dependency to easy packaging.
  * Remove deprecated dependencies paste/fixture.py.
  * Update setup.py to work with setuptools 50.1.0+
* Tue Aug  4 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.4.3:
  * Patch auth ticket to be python3 compatible.
* Fri Jul 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.4.2:
  * Correct sorting of items() in EvalHTMLFormatter.
  * Fix next in iterators in wsgilib.py.
* Thu Mar 26 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 3.4.0
  * Python 3 updates for use of StringIO and auth_tkt.py.
  * Use six.BytesIO when reading wsgi.input.
  * Allow binding IPv6 address when starting a server.
* Wed Jan 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 3.2.6
  * Correctly handle HEAD requests (to send empty body) when gzip encoding requested.
  * Use is_alive instead of isAlive for Python 3.9 compatibility.
  * Use encodebytes instead of deprecated encodestring.
  * Fix Python 2 and 3 compatibility for base64.
* Fri Dec 20 2019 Dirk Mueller <dmueller@suse.com>
- update to 3.2.3:
  * Correct ``100 Continue`` in Python 3
  * Avoid some reference cycles through tracebacks in httpserver.py
* Mon Oct  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.1:
  * no changelog
* Tue Sep 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.0:
  * Ensure unicode URLs work in TestApp.
  * Make LimitedLengthFile file return empty bytes.
  * Protect against accidental close in FieldStorage.
* Mon Jul 29 2019 pgajdos@suse.com
- version update to 3.1.0
  * Allow anything that can read() for a file-like response, not just
    a ``file`` instance.
* Fri Mar  8 2019 John Vandenberg <jayvdb@gmail.com>
- Add test_modified-fixup.patch to re-enable the test
- Remove build dependency on pytest-runner
- Update to v3.0.8
  * Fix quoting of bytestrings
* Tue Mar  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not bother with sphinx docu, it is online anyway
* Tue Mar  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.0.7:
  * Write bytestrings when calling wsgi_write_chunk
  * Revert "Remove use of OpenSSL.tsafe, which links to OpenSSL.SSL
* Thu Jan  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Disable test_modified as it fails on non 64b arches due to
  slightly different reported string
- Drop nose dep, not needed
- Fix URL to point to current homepage
* Mon Dec 17 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 3.0.5:
  * make tests pass after 2031
  * Use correct variable when building message for exception
  * Remove use of OpenSSL.tsafe, which links to OpenSSL.SSL anyways. (#16)
  * Fix error on httpserver shutdown
  * Add support for limited testing with travis-ci
  * Merged in hroncok/paste/py37 (pull request #41)
  * Don't raise StopIteration from generator, return instead
  * Fix up testing after switch to pytest
  * Make iterators Python3-compatible
  * Remove use of future
  * Don't raise StopIteration inside a generator
  * add link to read the docs to README
  * Release 3.0.2
  * Release 3.0.5
  * Prepare docs for publishing to RTFD
  * Run tox with Python 3.6 and 3.7
  * Prepare a 3.0.0 release
  * release 3.0.1
  * py3 fixes for form handling in paste.fixture (#8)
  * release 3.0.3
  * Special case py37
  * release 3.0.4
  * Switch from nose to pytest
  * Pytest fixes (#9)
  * paste.fixture: fix form offset handling (#12)
  * Add a simple .gitignore
  * Don't delete dict item while iterating over same dict (#14)
  * Depend on pytest instead of nose (#13)
  * Fix proxy test
  * Enable coverage reporting via codecov (#10)
  * Update README and setup.py for new location
  * Added tag 2.0.3 for changeset 768835f3c1b7
- Drop python37.patch. No longer needed
* Thu Oct 18 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix build on python 3.7:
  * python37.patch
* Tue Mar  6 2018 aplanas@suse.com
- Allows Recommends and Suggest in Fedora
* Tue Feb 27 2018 aplanas@suse.com
- Suggest only for SUSE
- Use %%{__python3} macro
* Wed Aug  9 2017 tbechtold@suse.com
- Remove unused BuildRequires
- Use Suggests for openid and flup. Both are optional deps
* Fri May  5 2017 toddrme2178@gmail.com
- Fix Provides/Obsoletes.
* Wed Apr 19 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Fri Jun  3 2016 tbechtold@suse.com
- update to 2.0.3:
  * prepare release 2.0.1
  * Added tag 2.0.1 for changeset a0ef0e57e057
  * set version to 2.0.2
  * Add tests/test_httpserver.py
  * Fix improper commas in request headers in wsgi_environ
  * tests/test_httpserver.py: Use `email` module instead of `mimetools`
  * tests/test_httpserver.py: Add test_environ_with_multiple_values
  * Make get all values of a header work on both Python 2 and 3
  * Make get_headers default to Python 3; fallback to Python 2
  * Make utility function private: _get_headers
  * Fix Python 3 issue in paste/fixture.py
  * test_wsgirequest_charset: Use UTF-8 instead of iso-8859-1
  * Replace cgi.parse_qsl w/ six.moves.urllib.parse.parse_sql
  * replace ``has_key`` method to ``in`` operator #9
  * Don't display invalid error message when socket in use
  * Update docs/news.txt for 2.0.2
  * Added tag 2.0.2 for changeset 53f5c2cd7f50
  * Python 3: App must always return binary type.
  * Python 3: Always encode params if passed as text types
  * Python 3: Don't mangle strangely encoded input
  * Python 3: Use the same python interpreter for CGI scripts.
  * Python 3: add workarounds for cgi.FieldStorage
  * Python 3: avoid spurious warnings
  * Python 3: dict.items() doesn't return a list anymore
  * Python 3: ignore exception details in doctests
  * Python 3: let html_quote() and url() always return the same type
  * Python 3: use compatible print syntax in example text
  * Change six requirement to >=1.4.0
  * tox.ini: Add py35 to envlist
  * Enable testing with pypy
  * tox.ini: Measure test coverage
  * paste.wsgilib.add_close: Add __next__ method
  * Add tests for `add_close` class
  * Uncomment/cleanup paste.wsgilib.app_close.__next__
  * Check paste.wsgilib.add_close._closed
  * Make add_close.next() leverage add_close.__next__()
  * Bump version to 2.0.3
  * Close branch 2.0.3
- Remove .orig files
* Sun Mar 13 2016 dmueller@suse.com
- add license.txt
* Fri May  8 2015 benoit.monin@gmx.fr
- update to version 2.0.1:
  * Fix setup.py for six dependency: move the six dependency from
    extras_require to install_requires
  * Port paste.proxy to Python 3
  * Fix paste.exceptions.serial_number_generator.hash_identifier()
    on Python 3
  * Fix paste.util.threadedprint.uninstall()
  * Add README.rst file
- additional changes from version 2.0:
  * Experimental Python 3 support
  * paste now requires the six module
  * Drop support of Python 2.5 and older
  * Fixed egg:Paste#cgi
  * In paste.httpserver: give a 100 Continue response even when the
    server has been configured as an HTTP/1.0 server
  * Fixed parsing of paths beginning with multiple forward slashes
  * Add tox.ini to run tests with tox on Python 2.6, 2.7 and 3.4
- add python-six as dependency
- add python-flup, python-nose and python-python-openid as test
  dependencies
- remove test requiring internet access: test_proxy.py
- reenable the tests
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu Nov 22 2012 saschpe@suse.de
- Require python-python-openid instead of non-existing python-openid
- Build HTML documentation
* Wed Jun 22 2011 saschpe@suse.de
- Initial version, obsoletes 'python-paste'
